"use client";

import dynamic from "next/dynamic";
import { useEffect, useState } from "react";
import { useMapEvents } from "react-leaflet";

// Dynamically import Leaflet components with no SSR
const MapContainer = dynamic(
	() => import("react-leaflet").then((mod) => mod.MapContainer),
	{ ssr: false }
);
const Marker = dynamic(
	() => import("react-leaflet").then((mod) => mod.Marker),
	{ ssr: false }
);
const TileLayer = dynamic(
	() => import("react-leaflet").then((mod) => mod.TileLayer),
	{ ssr: false }
);

// Import Leaflet CSS
import "leaflet/dist/leaflet.css";

// Define the icon outside the component to avoid re-creation
let icon: any = null;

interface MapProps {
	onLocationSelect: (lat: number, lng: number) => void;
	initialPosition?: [number, number];
}

// Saudi Arabia coordinates (centered)
const SAUDI_ARABIA_COORDS: [number, number] = [24.7136, 46.6753];

// LocationMarker component
function LocationMarker({ onLocationSelect, initialPosition }: { onLocationSelect: (lat: number, lng: number) => void, initialPosition?: [number, number] }) {
	const [position, setPosition] = useState<[number, number] | null>(
		initialPosition ? initialPosition : null
	);

	// Initialize map events
	const map = useMapEvents({
		click(e: any) {
			const { lat, lng } = e.latlng;
			setPosition([lat, lng]);
			onLocationSelect(lat, lng);
		},
	});

	// Update position when initialPosition changes
	useEffect(() => {
		if (initialPosition) {
			setPosition(initialPosition);
		}
	}, [initialPosition]);

	return position === null ? null : (
		<Marker position={position} icon={icon} />
	);
}

export function Map({ onLocationSelect, initialPosition = SAUDI_ARABIA_COORDS }: MapProps) {
	const [mounted, setMounted] = useState(false);
	const [mapError, setMapError] = useState(false);

	useEffect(() => {
		// Initialize Leaflet icon on the client side
		if (typeof window !== "undefined") {
			// Use dynamic import for Leaflet
			import("leaflet").then((L) => {
				icon = L.default.divIcon({
					className: "custom-marker",
					html: `<div style="
						background-color: #3b82f6;
						width: 24px;
						height: 24px;
						border-radius: 50%;
						border: 2px solid white;
						box-shadow: 0 0 0 2px #3b82f6;
					"></div>`,
					iconSize: [24, 24],
					iconAnchor: [12, 12],
					popupAnchor: [0, -12]
				});
				setMounted(true);
			}).catch(err => {
				console.error("Error loading Leaflet:", err);
				setMapError(true);
			});
		}
	}, []);

	if (!mounted || mapError) {
		return (
			<div className="h-[400px] w-full bg-muted rounded-md flex items-center justify-center">
				<p className="text-center text-muted-foreground">
					{mapError ? "حدث خطأ في تحميل الخريطة" : "جاري تحميل الخريطة..."}
				</p>
			</div>
		);
	}

	return (
		<MapContainer
			center={initialPosition}
			zoom={6}
			style={{ height: "400px", width: "100%", borderRadius: "12px" }}
			scrollWheelZoom={false}
			attributionControl={false}
		>
			<TileLayer
				url="https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
				attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
			/>
			<LocationMarker onLocationSelect={onLocationSelect} initialPosition={initialPosition} />
		</MapContainer>
	);
} 